#!/bin/bash

PACKAGE_NAME=ite

name=${0##*/}
BUILD_ROOT=${0%usr/share/ite/$name}
if [ "$BUILD_ROOT" == '/' ]; then
    echo 1>&2 The RPM package should be built in a SUBDIRECTORY.
    exit 1
fi
[ "$BUILD_ROOT" == "${BUILD_ROOT#/}" ] && BUILD_ROOT="`pwd`/$BUILD_ROOT"

SPEC_FILE=/tmp/buildrpm.$$.spec

if [ ! -d /$BUILD_ROOT ]; then
    echo 1>&2 "error: directory /$BUILD_ROOT does not exist."
    exit 2
fi

trap "rm -f $SPEC_FILE; exit" 0 1 2 3 15

cat <<END >$SPEC_FILE
%define ver	0.3
%define rel	18

Name:		$PACKAGE_NAME
Buildroot: 	$BUILD_ROOT
Requires:	vim-enhanced >= 6.0 vim-X11 >= 6.0 tetex tetex-latex
Requires:	xdvik >= 22.74.1 aspell >= 0.33 cct >= 0.5.0-3
Requires:	gawk grep sed
Provides:	ite
Version: 	%ver
Release:	%rel
Summary:	Integrated TeX Environments
Group:		Applications/Publishing
URL:		ftp://ftp.cc.ac.cn/pub/cct/ite
Packager:	Zhang Lin-bo <zlb@lsec.cc.ac.cn>
License:	non-commercial use

%description

This package provides an integrated TeX environment based on gvim
and basic CTeX support for Kile.

GVIM support:

    A shell script 'vtex' is provided to start gvim as an integrated
    TeX environment with a set of toolbar buttons for processing and
    previewing a LaTeX document. Forward and inverse source search
    are fully supported (requiring teTeX 2.0.2).

Kile support:

    Two shell scripts are provided.

    - kdvi, which is a symbolic link to kdvi-wrapper, is used to replace
      KDE's kdvi script for forward search.

    - kile-xdvik, is called by xdvik to return to the source document
      (inverse search).

Refer to the last section of ftp://ftp.cc.ac.cn/pub/cct/README.pdf
for more information.
  
%prep

%build

%install

%post

#if test -r /usr/bin/kdvi && ! grep -q "kdvi-wrapper" /usr/bin/kdvi; then
#    echo 1>&2 "Saving /usr/bin/kdvi as /usr/bin/kdvi.save"
#    /bin/mv -f /usr/bin/kdvi /usr/bin/kdvi.save
#fi
#/bin/rm -f /usr/bin/kdvi
#ln -s kdvi-wrapper /usr/bin/kdvi

if [ -r /usr/lib/aspell/en.multi ]; then
    aspell --lang=en create master /usr/share/ite/spell.dic \
	< /usr/share/ite/spell.words
elif [ -r /usr/lib/aspell/english.multi ]; then
    aspell --lang=english create master /usr/share/ite/spell.dic \
	< /usr/share/ite/spell.words
else
    aspell create master /usr/share/ite/spell.dic < /usr/share/ite/spell.words
fi

%postun

#if [ ! -r /usr/bin/kdvi ]; then
#    /bin/rm -f /usr/bin/kdvi
#    if test -f /usr/bin/kdvi.save; then
#	echo 1>&2 "Restoring /usr/bin/kdvi.save as /usr/bin/kdvi"
#	/bin/mv /usr/bin/kdvi.save /usr/bin/kdvi
#    fi
#fi

/bin/rmdir -p --ignore-fail-on-non-empty /usr/share/ite/* 2>/dev/null || true

%files
/etc/profile.d/vtex.csh
/etc/profile.d/vtex.sh
/usr/bin/kdvi-wrapper
/usr/bin/kile-xdvik
/usr/bin/vtex
/usr/share/ite/buildrpm.sh
/usr/share/ite/kile.txt
/usr/share/ite/bitmaps/Clean.xpm
/usr/share/ite/bitmaps/CTeX.xpm
/usr/share/ite/bitmaps/Empty.xpm
/usr/share/ite/bitmaps/Empty1.xpm
/usr/share/ite/bitmaps/Log.xpm
/usr/share/ite/bitmaps/Master.xpm
/usr/share/ite/bitmaps/Quick.xpm
/usr/share/ite/bitmaps/Search.xpm
/usr/share/ite/bitmaps/Spell.xpm
/usr/share/ite/bitmaps/XDvi.xpm
/usr/share/ite/ftplugin/latex-suite/templates/CCT-article.tex
/usr/share/ite/ftplugin/latex-suite/templates/CJK-article.tex
/usr/share/ite/logfilter
/usr/share/ite/setup.vim
/usr/share/ite/spell.dic
/usr/share/ite/spell.words
/usr/share/ite/spell.sh
/usr/share/ite/syntax/cct.vim
/usr/share/ite/syntax/tex.vim
/usr/share/ite/vtex.vim
/usr/share/ite/xpm.c

%changelog

* Fri Jan 30 2004 Zhang Linbo <zlb@lsec.cc.ac.cn>

- 0.3-18

  . /usr/bin/kdvi-wrapper: always sets XEDITOR to "kile-xdvik" for force
    returning back to kile, ignoring current settings of XEDITOR.

* Tue Jan 20 2004 Zhang Linbo <zlb@lsec.cc.ac.cn>

- 0.3-17: fixed some compatibility issues with vim >= 6.2.180

  . vtex.vim: add 'set cpoptions-=C' to allow continuation lines

  . vtex.vim: commented out the line 'aunmenu Tools.Make'

  . MainFile(): use file in the current buffer instead of buffer 1 as the
    default main file if the .latexmain file does not exist.

  . In 6.2.180: <CR> has no effect for the ToolBar buttons.
    Fixed by moving the 'am ...' lines from vtex.vim to setup.vim (why?)

* Sat Nov 15 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/share/ite/ftplugin/latex-suite/templates/CCT-article.tex revised.

* Thu Nov  6 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- fix a small bug in /usr/bin/vtex such that correct Chinese fontset is
  used for non-GTK+ versions of gvim.

* Tue Oct 21 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/share/ite/spell.sh: improve scanning of the math and verbatim
  environments.

* Wed Oct 15 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/share/ite/spell.sh

  . Add support for aspell-0.50 (using appropriate '--lang=' option)

  . Fix some bugs in /usr/share/ite/spell.sh

* Wed Oct  1 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- vtex.vim: 

  . call Tex_SetupErrorWindow() in CTeX_CTeX() to setup the .log preview window

  . replace 'let g:Tex_IgnoredWarnings = ""' with 'let g:Tex_IgnoreLevel = 0'

- setup.vim: keep the 'Set Ignore Level' menu entry s.t. user can change the
  level of display of error messages.

* Wed Sep  3 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- modified spell.sh to work with gawk 3.1.3-2

* Thu Jul 31 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- added support for GTK2 version of Gvim-6.2

* Mon Jul 21 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- added symlink cct.vim->tex.vim in /usr/share/ite/syntax/

* Fri Jun 27 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/share/vtex.vim: added 'set grepprg=grep\ -nH\ $*'

- added LaTeX-Suite templates "CCT-article" and "CJK-article"

- kdvi-wrapper: use '-gamma 0.66' if dvi file is CCT format.

- spell.sh: processing '\\', '\%', '%', and '\$' 

* Wed Jun 25 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/bin/vtex: checking existence of the master file defined by the
  latexmain file.

* Tue Jun 24 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- added /etc/profile.d/vtex.sh and /etc/profile.d/vtex.csh

- /usr/bin/vtex:

  . set servername to "VTEX-{inode number}A" (with 'A' appended because
    sometimes Gvim appends '1' to the servername), and only compare the
    leading part when matching servernames.

  . first looks for .latexmain file when constructing servername.

* Sun Jun 22 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- /usr/bin/vtex, /usr/bin/kile-xdvik: code for processing the 'ctextemp_'
  prefix removed (no longer necessary with ctex-0.2.1)

- /usr/share/ite/setup.vim: commented out the lines:

	syntax sync minlines=100
	set lines=25
	set columns=80

* Wed Jun 18 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- use the QuickFix mode for compiling.

- removed the 'make' button which is redundant now.

- compatibility with LaTeX-Suite in determining the master filename,
  i.e., if 'mainfile.latexmain' exists in the current directory then
  use 'mainfile' as the master file.

* Sat Jun 14 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- cct.vim renamed to tex.vim

- "runtimepath" set to: "~/.vim,/usr/share/ite,..." in vtex.vim

- added latexSuite support and created the ite-latexSuite package.

* Thu Jun 12 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- set foldmethod=marker and set foldmarker=<<<,>>> in cct.vim

* Sun Jun 08 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- new font selection order: "isas-song ti" then "misc-zysong18030" then
  "*-*", the first one which provides both gb2312.1980-0 and iso10646-1
  charsets is used.

* Fri Jun 06 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- use zysong18030 font by default if it's available

* Wed Jun 04 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- don't change LC_CTYPE (it seems that gvim works well with the
  zh_CN.GB18030 locale, not as vim).

- added toolbar button for spelling check

* Tue Jun 03 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- syntax hilighting for \verb* and {verbatim*} (bug in tex.vim)

* Mon Jun 02 2003 Zhang Linbo <zlb@lsec.cc.ac.cn>

- removed dependency on CCT and use 'latex' instead of 'ctex' if the latter
  is not available.

- set tw=78, language=cn-euc and add 'tcqmM' to 'formatoptions'

END

rpmbuild -bb $SPEC_FILE
