#!/bin/bash

export LC_ALL=C
export LANG=C

# `grep -v "$rexp"' can be used to filter GBK chars
###ECHO="/bin/echo -e"
###rexp="[`$ECHO '\200'`-`$ECHO '\376'`][`$ECHO '\080'`-`$ECHO '\376'`]"

# The command below does not work with gawk 3.1.3-2
####awk '{print gensub(/[\200-\376][\080-\377]/, " ", "g")}' | \

# Check for existence of local dictionary
if [ -r /usr/lib/aspell/en.multi ]; then
    ASPELL="aspell --lang=en"
elif [ -r /usr/lib/aspell/english.multi ]; then
    ASPELL="aspell --lang=english"
else
    ASPELL="aspell"
fi
DIC="--add-extra-dicts=/usr/share/ite/spell.dic"
if [ -r ${HOME}/.ite/spell.words ]; then
    # check for the format of the .dic file
    if [ ${HOME}/.ite/spell.words -nt ${HOME}/.ite/spell.dic -o \
	"`cat ${HOME}/.ite/spell.ver 2>/dev/null`" != "`aspell --version`" ]
    then
	$ASPELL create master ${HOME}/.ite/spell.dic < ${HOME}/.ite/spell.words
	aspell --version >${HOME}/.ite/spell.ver
    fi
    DIC="${DIC},${HOME}/.ite/spell.dic"
fi

#
# Note: words in [...] and |...| (frequently used with shortvrb package)
#	are ignored.
#
# awk is used to filter multiple-line blocks like $ ... $, $$ ... $$,
# \begin{verbatim} ... \end{verbatim}, etc.
#
# Note: don't filter \begin{comment} ... \end{comment},
#	it's contents should be checked!!!
#

VIMFILE=`mktemp /tmp/itespell.vim.XXXXXX`
LSTFILE=`mktemp /tmp/itespell.lst.XXXXXX`
#
# SYNTAX_HIGHLIGHT == 0 ==> define search patterns for erroneour words
export SYNTAX_HIGHLIGHT=0

trap "/bin/rm -f $LSTFILE" 0 1 2 3 15

cat $1 | \
    awk '{
	    for (i=1; i <= length(); i++) {
		c=substr($0, i, 1)
		if (c<="\200") printf "%s", c; else {printf "%s", " "; i++;}
	    }
	    printf "\n"
	}' | \
    sed -e 's/\\\\/ /g' -e 's/\\%/ /g' \
	-e 's/\(^\|[^\\]\)%.*$/\1/' \
	-e 's/\\\$/ /g' \
	-e 's/\$[^\$]\+\$/ /g' \
	| \
    awk '
	function check_skip(start, end,    i)
	{
	    if ((i=index(line, start)) > 0) {
		if (pos0 >= i) {
		    pos0 = i - 1
		    pos1 = i + length(start)
		    skipend = end
		}
	    }
	}

	BEGIN {
	    skipend = ""
	}
	
	{
	    line = $0

	    while ( line != "" ) {
		if (skipend != "") {
		    if ((i = index(line, skipend)) > 0) {
			line = substr(line, i + length(skipend))
			skipend = ""
		    } else {
			line = ""
			continue
		    }
		}

		/* check for \verb* and \verb */
		if ((i = match(line, /\\verb\*/)) > 0) {
		    pos0 = i - 1
		    skipend = substr(line, i+6, 1)
		    pos1 = i + 7
		} else if ((i = match(line, /\\verb[^[:alpha:]]/)) > 0) {
		    pos0 = i - 1
		    skipend = substr(line, i+5, 1)
		    pos1 = i + 6
		} else {
		    pos0 = length(line)
		    pos1 = pos0 + 1
		}

		check_skip("\\begin{verbatim}", "\\end{verbatim}")
		check_skip("\\begin{verbatim*}", "\\end{verbatim*}")
		check_skip("$$", "$$")
		check_skip("$", "$")
		check_skip("\\(", "\\)")
		check_skip("\\[", "\\]")
		check_skip("\\begin{math}", "\\end{math}")
		check_skip("\\begin{displaymath}", "\\end{displaymath}")
		check_skip("\\begin{equation}", "\\end{equation}")
		check_skip("\\begin{eqnarray}", "\\end{eqnarray}")
		check_skip("\\begin{eqnarray*}", "\\end{eqnarray*}")
		check_skip("\\begin{gather}", "\\end{gather}")
		check_skip("\\begin{gather*}", "\\end{gather*}")
		check_skip("\\begin{multline}", "\\end{multline}")
		check_skip("\\begin{multline*}", "\\end{multline*}")
		check_skip("\\begin{align}", "\\end{align}")
		check_skip("\\begin{align*}", "\\end{align*}")
		check_skip("\\begin{flalign}", "\\end{flalign}")
		check_skip("\\begin{flalign*}", "\\end{flalign*}")
		check_skip("\\begin{alignat}", "\\end{alignat}")
		check_skip("\\begin{alignat*}", "\\end{alignat*}")

		if (pos0 > 0) print substr(line, 1, pos0)
		line = substr(line, pos1)
	    }
	}
	' | \
    $ASPELL -l --mode=tex $DIC | sort -u | tee $LSTFILE | \
    awk '
	BEGIN {
	    syntax_hl = ENVIRON["SYNTAX_HIGHLIGHT"]

	    if (syntax_hl != 0) {
		printf "syntax clear\n"
	    } else {
		first_call = 1
	    }
	}

	{
	    if (syntax_hl != 0) {
		printf "syntax match SpellErrors \"\\<%s\\>\"\n", $0
	    } else if (first_call != 0) {
		printf "let s:pattern = \"\\\\<%s\\\\>\"\n", $0
		first_call = 0
	    } else {
		printf "let s:pattern = s:pattern . \"\\\\|\\\\<%s\\\\>\"\n",$0
	    }
	}

	END {
	    if (syntax_hl != 0) {
		#printf "highlight link SpellErrors ErrorMsg\n\n" ;
		printf "highlight SpellErrors guifg=white guibg=red\n\n" ;
	    } else {
		printf "let @/ = s:pattern\n"
	    }
	}
	' >$VIMFILE

if test -s $LSTFILE; then
    /bin/rm -f ${1}.err
    if /bin/cp -f $LSTFILE ${1}.err; then
	echo "15vsplit +e! ${1}.err" >> $VIMFILE
	echo "set readonly" >> $VIMFILE
    fi
    if [ "$SYNTAX_HIGHLIGHT" != "0" ]; then
	cat <<END >> $VIMFILE
	    echo "    "
	    echo "*****************************************************"
	    echo " ƴдøʾҲ, 󵥴г"
	    echo " ƴдĴ ':edit' ָʾ"
	    echo "*****************************************************"
	    echo "    "
END
    else
	cat <<END >> $VIMFILE
	    echo "    "
	    echo "*****************************************************"
	    echo " 󵥴രг, Ҳരڡ󵥴ѱ"
	    echo " óɵǰͼ, Ĵ \\"/<س>\\" ҡ"
	    echo "*****************************************************"
	    echo "    "
END
    fi
else
    cat <<END > $VIMFILE
	echo "    "
	echo "****************"
	echo " ûƴд"
	echo "****************"
	echo "    "
END
fi

echo "let dummy = system(\"/bin/rm -f $VIMFILE\")" >> $VIMFILE

echo $VIMFILE
